@@ -1,7 +1,7 @@
 import os
 import unittest
 from httpretty import HTTPretty, httprettified
-from fanart.movie import Movie
+from fanart.movie import *
 from fanart.tests import LOCALDIR
 os.environ['FANART_APIKEY'] = 'e3c7f0d0beeaf45b3a0dd3b9dd8a3338'
 
@@ -18,3 +18,4 @@ class TvItemTestCase(unittest.TestCase):
         )
         hunger_games = Movie.get(id=70160)
         self.assertEqual(hunger_games.tmdbid, '70160')
+        self.assertEqual(hunger_games, eval(repr(hunger_games)))
